# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/permission_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)fsai_grpc_api/protos/permission_api.proto\x1a fsai_grpc_api/protos/utils.proto\"7\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07role_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\"@\n\x1d\x46indOrCreatePermissionRequest\x12\x1f\n\npermission\x18\x01 \x01(\x0b\x32\x0b.Permission\"c\n\x1e\x46indOrCreatePermissionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1f\n\npermission\x18\x02 \x01(\x0b\x32\x0b.Permission\"9\n\x16ListPermissionsRequest\x12\x1f\n\npermission\x18\x01 \x01(\x0b\x32\x0b.Permission\"]\n\x17ListPermissionsResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bpermissions\x18\x02 \x03(\x0b\x32\x0b.Permission2\xb0\x01\n\rPermissionApi\x12Y\n\x16\x46indOrCreatePermission\x12\x1e.FindOrCreatePermissionRequest\x1a\x1f.FindOrCreatePermissionResponse\x12\x44\n\x0fListPermissions\x12\x17.ListPermissionsRequest\x1a\x18.ListPermissionsResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.permission_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PERMISSION._serialized_start=79
  _PERMISSION._serialized_end=134
  _FINDORCREATEPERMISSIONREQUEST._serialized_start=136
  _FINDORCREATEPERMISSIONREQUEST._serialized_end=200
  _FINDORCREATEPERMISSIONRESPONSE._serialized_start=202
  _FINDORCREATEPERMISSIONRESPONSE._serialized_end=301
  _LISTPERMISSIONSREQUEST._serialized_start=303
  _LISTPERMISSIONSREQUEST._serialized_end=360
  _LISTPERMISSIONSRESPONSE._serialized_start=362
  _LISTPERMISSIONSRESPONSE._serialized_end=455
  _PERMISSIONAPI._serialized_start=458
  _PERMISSIONAPI._serialized_end=634
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/workflow_analyzer_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n0fsai_grpc_api/protos/workflow_analyzer_api.proto\"M\n GetEstimatesByTotalAoiKm2Request\x12\x15\n\rtotal_aoi_km2\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"L\n GetEstimatesByTotalImagesRequest\x12\x14\n\x0ctotal_images\x18\x01 \x01(\x05\x12\x12\n\nbatch_size\x18\x02 \x01(\x05\"4\n\x1eGetEstimatesByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"v\n\x14WorkflowAnalyzerCost\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"w\n\x15WorkflowAnalyzerHours\x12\x1b\n\x13\x66\x65\x61ture_acquisition\x18\x01 \x01(\x02\x12\x19\n\x11image_acquisition\x18\x02 \x01(\x02\x12\x17\n\x0fimage_inference\x18\x03 \x01(\x02\x12\r\n\x05total\x18\x04 \x01(\x02\"|\n\x18WorkflowAnalyzerResponse\x12\x14\n\x0c\x62\x61tch_number\x18\x01 \x01(\x05\x12#\n\x04\x63ost\x18\x05 \x01(\x0b\x32\x15.WorkflowAnalyzerCost\x12%\n\x05hours\x18\x06 \x01(\x0b\x32\x16.WorkflowAnalyzerHours2\xa2\x02\n\x13WorkflowAnalyzerApi\x12Y\n\x19GetEstimatesByTotalAoiKm2\x12!.GetEstimatesByTotalAoiKm2Request\x1a\x19.WorkflowAnalyzerResponse\x12Y\n\x19GetEstimatesByTotalImages\x12!.GetEstimatesByTotalImagesRequest\x1a\x19.WorkflowAnalyzerResponse\x12U\n\x17GetEstimatesByMissionId\x12\x1f.GetEstimatesByMissionIdRequest\x1a\x19.WorkflowAnalyzerResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.workflow_analyzer_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETESTIMATESBYTOTALAOIKM2REQUEST._serialized_start=52
  _GETESTIMATESBYTOTALAOIKM2REQUEST._serialized_end=129
  _GETESTIMATESBYTOTALIMAGESREQUEST._serialized_start=131
  _GETESTIMATESBYTOTALIMAGESREQUEST._serialized_end=207
  _GETESTIMATESBYMISSIONIDREQUEST._serialized_start=209
  _GETESTIMATESBYMISSIONIDREQUEST._serialized_end=261
  _WORKFLOWANALYZERCOST._serialized_start=263
  _WORKFLOWANALYZERCOST._serialized_end=381
  _WORKFLOWANALYZERHOURS._serialized_start=383
  _WORKFLOWANALYZERHOURS._serialized_end=502
  _WORKFLOWANALYZERRESPONSE._serialized_start=504
  _WORKFLOWANALYZERRESPONSE._serialized_end=628
  _WORKFLOWANALYZERAPI._serialized_start=631
  _WORKFLOWANALYZERAPI._serialized_end=921
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/team_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#fsai_grpc_api/protos/team_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xc4\x01\n\x04Team\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04name\x18\x02 \x01(\t\x12.\n\ncreated_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ncreated_by\x18\x06 \x01(\x05\"(\n\x11\x43reateTeamRequest\x12\x13\n\x04team\x18\x01 \x01(\x0b\x32\x05.Team\"K\n\x12\x43reateTeamResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04team\x18\x02 \x01(\x0b\x32\x05.Team2@\n\x07TeamApi\x12\x35\n\nCreateTeam\x12\x12.CreateTeamRequest\x1a\x13.CreateTeamResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.team_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TEAM._serialized_start=107
  _TEAM._serialized_end=303
  _CREATETEAMREQUEST._serialized_start=305
  _CREATETEAMREQUEST._serialized_end=345
  _CREATETEAMRESPONSE._serialized_start=347
  _CREATETEAMRESPONSE._serialized_end=422
  _TEAMAPI._serialized_start=424
  _TEAMAPI._serialized_end=488
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/review_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%fsai_grpc_api/protos/review_api.proto\":\n$GetNextReviewImageByMissionIdRequest\x12\x12\n\nmission_id\x18\x01 \x01(\x05\"9\n%GetNextReviewImageByMissionIdResponse\x12\x10\n\x08image_id\x18\x01 \x01(\x05\x32{\n\tReviewApi\x12n\n\x1dGetNextReviewImageByMissionId\x12%.GetNextReviewImageByMissionIdRequest\x1a&.GetNextReviewImageByMissionIdResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.review_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST._serialized_start=41
  _GETNEXTREVIEWIMAGEBYMISSIONIDREQUEST._serialized_end=99
  _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE._serialized_start=101
  _GETNEXTREVIEWIMAGEBYMISSIONIDRESPONSE._serialized_end=158
  _REVIEWAPI._serialized_start=160
  _REVIEWAPI._serialized_end=283
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/signed_url_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n)fsai_grpc_api/protos/signed_url_api.proto\"\'\n\x13GetSignedUrlRequest\x12\x10\n\x08url_path\x18\x01 \x01(\t\"*\n\x14GetSignedUrlResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t\"`\n GetSignedMissionExportUrlRequest\x12\x13\n\x0bworkflow_id\x18\x01 \x01(\x05\x12\x14\n\x0cpackage_type\x18\x02 \x01(\t\x12\x11\n\tfile_type\x18\x03 \x01(\t\"7\n!GetSignedMissionExportUrlResponse\x12\x12\n\nsigned_url\x18\x01 \x01(\t2\xaf\x01\n\x0cSignedUrlApi\x12;\n\x0cGetSignedUrl\x12\x14.GetSignedUrlRequest\x1a\x15.GetSignedUrlResponse\x12\x62\n\x19GetSignedMissionExportUrl\x12!.GetSignedMissionExportUrlRequest\x1a\".GetSignedMissionExportUrlResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.signed_url_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GETSIGNEDURLREQUEST._serialized_start=45
  _GETSIGNEDURLREQUEST._serialized_end=84
  _GETSIGNEDURLRESPONSE._serialized_start=86
  _GETSIGNEDURLRESPONSE._serialized_end=128
  _GETSIGNEDMISSIONEXPORTURLREQUEST._serialized_start=130
  _GETSIGNEDMISSIONEXPORTURLREQUEST._serialized_end=226
  _GETSIGNEDMISSIONEXPORTURLRESPONSE._serialized_start=228
  _GETSIGNEDMISSIONEXPORTURLRESPONSE._serialized_end=283
  _SIGNEDURLAPI._serialized_start=286
  _SIGNEDURLAPI._serialized_end=461
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/role_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#fsai_grpc_api/protos/role_api.proto\x1a fsai_grpc_api/protos/utils.proto\"1\n\x04Role\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07team_id\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\".\n\x17\x46indOrCreateRoleRequest\x12\x13\n\x04role\x18\x01 \x01(\x0b\x32\x05.Role\"Q\n\x18\x46indOrCreateRoleResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04role\x18\x02 \x01(\x0b\x32\x05.Role\"\'\n\x10ListRolesRequest\x12\x13\n\x04role\x18\x01 \x01(\x0b\x32\x05.Role\"K\n\x11ListRolesResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x14\n\x05roles\x18\x02 \x03(\x0b\x32\x05.Role2\x86\x01\n\x07RoleApi\x12G\n\x10\x46indOrCreateRole\x12\x18.FindOrCreateRoleRequest\x1a\x19.FindOrCreateRoleResponse\x12\x32\n\tListRoles\x12\x11.ListRolesRequest\x1a\x12.ListRolesResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.role_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ROLE._serialized_start=73
  _ROLE._serialized_end=122
  _FINDORCREATEROLEREQUEST._serialized_start=124
  _FINDORCREATEROLEREQUEST._serialized_end=170
  _FINDORCREATEROLERESPONSE._serialized_start=172
  _FINDORCREATEROLERESPONSE._serialized_end=253
  _LISTROLESREQUEST._serialized_start=255
  _LISTROLESREQUEST._serialized_end=294
  _LISTROLESRESPONSE._serialized_start=296
  _LISTROLESRESPONSE._serialized_end=371
  _ROLEAPI._serialized_start=374
  _ROLEAPI._serialized_end=508
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/team_member_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*fsai_grpc_api/protos/team_member_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xca\x01\n\nTeamMember\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0f\n\x07user_id\x18\x02 \x01(\x05\x12\x0f\n\x07team_id\x18\x03 \x01(\x05\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ndeleted_at\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"A\n\x1d\x46indOrCreateTeamMemberRequest\x12 \n\x0bteam_member\x18\x01 \x01(\x0b\x32\x0b.TeamMember\"d\n\x1e\x46indOrCreateTeamMemberResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12 \n\x0bteam_member\x18\x02 \x01(\x0b\x32\x0b.TeamMember2j\n\rTeamMemberApi\x12Y\n\x16\x46indOrCreateTeamMember\x12\x1e.FindOrCreateTeamMemberRequest\x1a\x1f.FindOrCreateTeamMemberResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.team_member_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TEAMMEMBER._serialized_start=114
  _TEAMMEMBER._serialized_end=316
  _FINDORCREATETEAMMEMBERREQUEST._serialized_start=318
  _FINDORCREATETEAMMEMBERREQUEST._serialized_end=383
  _FINDORCREATETEAMMEMBERRESPONSE._serialized_start=385
  _FINDORCREATETEAMMEMBERRESPONSE._serialized_end=485
  _TEAMMEMBERAPI._serialized_start=487
  _TEAMMEMBERAPI._serialized_end=593
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/source_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n%fsai_grpc_api/protos/source_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\x90\x01\n\x06Source\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0c\n\x04slug\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"(\n\rSourceRequest\x12\x17\n\x06source\x18\x01 \x01(\x0b\x32\x07.Source\"K\n\x0eSourceResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x17\n\x06source\x18\x02 \x01(\x0b\x32\x07.Source2B\n\tSourceApi\x12\x35\n\x12\x46indOrCreateSource\x12\x0e.SourceRequest\x1a\x0f.SourceResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.source_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SOURCE._serialized_start=109
  _SOURCE._serialized_end=253
  _SOURCEREQUEST._serialized_start=255
  _SOURCEREQUEST._serialized_end=295
  _SOURCERESPONSE._serialized_start=297
  _SOURCERESPONSE._serialized_end=372
  _SOURCEAPI._serialized_start=374
  _SOURCEAPI._serialized_end=440
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/user_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n#fsai_grpc_api/protos/user_api.proto\x1a fsai_grpc_api/protos/utils.proto\">\n\x0bPermissions\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0c\n\x04\x65num\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"s\n\x04User\x12\n\n\x02id\x18\x01 \x01(\x05\x12\r\n\x05\x66irst\x18\x02 \x01(\t\x12\x0c\n\x04last\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x10\n\x08password\x18\x05 \x01(\t\x12!\n\x0bpermissions\x18\x06 \x03(\x0b\x32\x0c.Permissions\"(\n\x11\x43reateUserRequest\x12\x13\n\x04user\x18\x01 \x01(\x0b\x32\x05.User\"K\n\x12\x43reateUserResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04user\x18\x02 \x01(\x0b\x32\x05.User\"-\n\x16\x46indUserByEmailRequest\x12\x13\n\x04user\x18\x01 \x01(\x0b\x32\x05.User\"P\n\x17\x46indUserByEmailResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x13\n\x04user\x18\x02 \x01(\x0b\x32\x05.User\":\n\x17\x41uthenticateUserRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"K\n\x18\x41uthenticateUserResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\r\n\x05valid\x18\x02 \x01(\x08\x32\xcf\x01\n\x07UserApi\x12\x35\n\nCreateUser\x12\x12.CreateUserRequest\x1a\x13.CreateUserResponse\x12\x44\n\x0f\x46indUserByEmail\x12\x17.FindUserByEmailRequest\x1a\x18.FindUserByEmailResponse\x12G\n\x10\x41uthenticateUser\x12\x18.AuthenticateUserRequest\x1a\x19.AuthenticateUserResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.user_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PERMISSIONS._serialized_start=73
  _PERMISSIONS._serialized_end=135
  _USER._serialized_start=137
  _USER._serialized_end=252
  _CREATEUSERREQUEST._serialized_start=254
  _CREATEUSERREQUEST._serialized_end=294
  _CREATEUSERRESPONSE._serialized_start=296
  _CREATEUSERRESPONSE._serialized_end=371
  _FINDUSERBYEMAILREQUEST._serialized_start=373
  _FINDUSERBYEMAILREQUEST._serialized_end=418
  _FINDUSERBYEMAILRESPONSE._serialized_start=420
  _FINDUSERBYEMAILRESPONSE._serialized_end=500
  _AUTHENTICATEUSERREQUEST._serialized_start=502
  _AUTHENTICATEUSERREQUEST._serialized_end=560
  _AUTHENTICATEUSERRESPONSE._serialized_start=562
  _AUTHENTICATEUSERRESPONSE._serialized_end=637
  _USERAPI._serialized_start=640
  _USERAPI._serialized_end=847
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: fsai_grpc_api/protos/detection_api.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from fsai_grpc_api.protos import utils_pb2 as fsai__grpc__api_dot_protos_dot_utils__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(fsai_grpc_api/protos/detection_api.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a fsai_grpc_api/protos/utils.proto\"\xaa\x01\n\tDetection\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x1c\n\tgeo_point\x18\x02 \x01(\x0b\x32\t.GeoPoint\x12\x13\n\x0b\x63\x61tegory_id\x18\x03 \x01(\x05\x12.\n\ncreated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\nupdated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"1\n\x10\x44\x65tectionRequest\x12\x1d\n\tdetection\x18\x01 \x01(\x0b\x32\n.Detection\"T\n\x11\x44\x65tectionResponse\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12\x1d\n\tdetection\x18\x02 \x01(\x0b\x32\n.Detection\"^\n\x12\x44\x65tectionResponses\x12 \n\x0b\x63hange_type\x18\x01 \x01(\x0e\x32\x0b.ChangeType\x12&\n\ndetections\x18\x02 \x03(\x0b\x32\x12.DetectionResponse2N\n\x0c\x44\x65tectionApi\x12>\n\x15\x46indOrCreateDetection\x12\x11.DetectionRequest\x1a\x12.DetectionResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'fsai_grpc_api.protos.detection_api_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DETECTION._serialized_start=112
  _DETECTION._serialized_end=282
  _DETECTIONREQUEST._serialized_start=284
  _DETECTIONREQUEST._serialized_end=333
  _DETECTIONRESPONSE._serialized_start=335
  _DETECTIONRESPONSE._serialized_end=419
  _DETECTIONRESPONSES._serialized_start=421
  _DETECTIONRESPONSES._serialized_end=515
  _DETECTIONAPI._serialized_start=517
  _DETECTIONAPI._serialized_end=595
# @@protoc_insertion_point(module_scope)
